@@ -22,10 +22,8 @@
 #include <string.h> // memcmp, memcpy
 #include <stdlib.h> // malloc, free
 
-#include <libdivecomputer/shearwater_predator.h>
-
+#include "shearwater_predator.h"
 #include "shearwater_common.h"
-
 #include "context-private.h"
 #include "device-private.h"
 #include "array.h"
@@ -59,9 +57,12 @@ static const dc_device_vtable_t shearwater_predator_device_vtable = {
 	NULL, /* write */
 	shearwater_predator_device_dump, /* dump */
 	shearwater_predator_device_foreach, /* foreach */
+	NULL, /* timesync */
 	shearwater_predator_device_close /* close */
 };
 
+static dc_status_t
+shearwater_predator_extract_dives (dc_device_t *device, const unsigned char data[], unsigned int size, dc_dive_callback_t callback, void *userdata);
 
 dc_status_t
 shearwater_predator_device_open (dc_device_t **out, dc_context_t *context, const char *name)
@@ -156,8 +157,8 @@ shearwater_predator_device_foreach (dc_device_t *abstract, dc_dive_callback_t ca
 	unsigned char *data = dc_buffer_get_data (buffer);
 	dc_event_devinfo_t devinfo;
 	devinfo.model = data[0x2000D];
-	devinfo.firmware = data[0x2000A];
-	devinfo.serial = array_uint32_le (data + 0x20002);
+	devinfo.firmware = bcd2dec (data[0x2000A]);
+	devinfo.serial = array_uint32_be (data + 0x20002);
 	device_event_emit (abstract, DC_EVENT_DEVINFO, &devinfo);
 
 	rc = shearwater_predator_extract_dives (abstract, data, SZ_MEMORY, callback, userdata);
@@ -339,7 +340,7 @@ shearwater_predator_extract_petrel (dc_device_t *abstract, const unsigned char d
 }
 
 
-dc_status_t
+static dc_status_t
 shearwater_predator_extract_dives (dc_device_t *abstract, const unsigned char data[], unsigned int size, dc_dive_callback_t callback, void *userdata)
 {
 	if (abstract && !ISINSTANCE (abstract))
